==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "About" : "Tietoja",
    "Extend your cloud" : "Laajenna pilveäsi",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
    "Browse the app store" : "Selaa sovelluskauppaa",
    "Stay in sync" : "Pysy synkronoituna",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "Desktop client" : "Työpöytäsovellus",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi %siin",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
    "User manual" : "Käyttäjän ohje",
    "Admin manual" : "Ylläpitäjän ohje",
    "Developer manual" : "Kehittäjän ohje",
    "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
    "Enterprise support" : "Yritystuki",
    "Get enterprise support" : "Hanki yritystason tukea",
    "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
    "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
    "Open Standards and Interoperability" : "Avoimet standardit ja yhteentoimivuus",
    "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
    "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
    "Previous" : "Edellinen",
    "Next" : "Seuraava",
    "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Käytä ja jaa tiedostoja, kalentereita, yhteystietoja, sähköpostia ja paljon muuta miltä tahansa laitteelta omilla ehdoillasi",
    "Connect your Calendar" : "Yhdistä kalenteriisi",
    "Connect your Contacts" : "Yhdistä yhteystietoihisi",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Lisätietoa on saatavilla <a target=\"_blank\" href=\"%s\">dokumentaatiossa</a> ja <a target=\"_blank\" href=\"%s\">verkkosivustollamme</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Jos pidät Nextcloudista, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud on mahtava avoimen lähdekoodin ohjelmisto tiedostojen synkronointiin ja jakamiseen. Voit ladata sen vapaasti osoitteesta https://nextcloud.com\">suosittele sitä ystävillesi</a> ja <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">osallistu sen kehittämiseen</a>!",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jos haluat tukea projektia, {contributeopen}auta kehittämällä{linkclose} tai {contributeopen}levitä sanaa{linkclose}!",
    "Show First Run Wizard again" : "Näytä ensimmäisen käyttökerran avustaja uudelleen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/fi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Ensimmäisen käyttökerran avustaja",
    "Add your profile information! For example your email is needed to reset your password." : "Lisää profiilitietosi! Esimerkiksi sähköpostiosoitettasi tarvitaan salasanan palauttamiseen.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva ja koko nimi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Lisää profiilitietosi! Lisää koko nimesi, jotta sinut on helpompi tunnistaa.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Lisää profiilitietosi! Lisää profiilikuva, jotta sinut on helpompi tunnistaa.",
    "About" : "Tietoja",
    "Extend your cloud" : "Laajenna pilveäsi",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Tietoturva- ja tunnistautumisominaisuuksia kuten kaksivaiheinen tunnistautuminen, kertakirjautuminen ja suoja kiristysohjelmia vastaan",
    "Browse the app store" : "Selaa sovelluskauppaa",
    "Stay in sync" : "Pysy synkronoituna",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud mahdollistaa pääsyn tiedostoihisi sijainnistasi riippumatta.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Helppokäyttöiset työpöytä- ja mobiilisovellukset ovat saatavilla kaikille suosituimmille alustoille ilman kustannuksia!",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "Desktop client" : "Työpöytäsovellus",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "Connect your desktop apps to %s" : "Yhdistä työpöytäsovelluksesi %siin",
    "Connect your calendar" : "Yhdistä kalenteriisi",
    "Connect your contacts" : "Yhdistä yhteystietoihisi",
    "Access files via WebDAV" : "Käytä tiedostoja WebDAVin välityksellä",
    "The Nextcloud documentation for home users:" : "Nextcloud-ohjeet kotikäyttäjille:",
    "User manual" : "Käyttäjän ohje",
    "Admin manual" : "Ylläpitäjän ohje",
    "Developer manual" : "Kehittäjän ohje",
    "You can also ask for help in our community support channels:" : "Voit kysyä apua myös yhteisön tukikanavilta:",
    "Become part of the Community" : "Ryhdy osaksi yhteisöä",
    "Enterprise support" : "Yritystuki",
    "Get enterprise support" : "Hanki yritystason tukea",
    "A safe home for all your data" : "Turvallinen koti kaikille tiedoillesi",
    "Host your data and files where you decide" : "Säilytä tietosi ja tiedostosi missä itse haluat",
    "Open Standards and Interoperability" : "Avoimet standardit ja yhteentoimivuus",
    "100%% Open Source & community-focused" : "100%% avointa lähdekoodia ja yhteisökeskeisyyttä",
    "Connect other apps to %s" : "Yhdistä muita sovelluksia %siin",
    "Previous" : "Edellinen",
    "Next" : "Seuraava",
    "Start using Nextcloud" : "Aloita Nextcloudin käyttäminen",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Jos haluat tukea projektia, {contributeopen}auta kehittämällä{linkclose} tai {contributeopen}levitä sanaa{linkclose}!",
    "Show First Run Wizard again" : "Näytä ensimmäisen käyttökerran avustaja uudelleen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Käytä ja jaa tiedostoja, kalentereita, yhteystietoja, sähköpostia ja paljon muuta miltä tahansa laitteelta omilla ehdoillasi",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Lisätietoa on saatavilla <a target=\"_blank\" href=\"%s\">dokumentaatiossa</a> ja <a target=\"_blank\" href=\"%s\">verkkosivustollamme</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Jos pidät Nextcloudista, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud on mahtava avoimen lähdekoodin ohjelmisto tiedostojen synkronointiin ja jakamiseen. Voit ladata sen vapaasti osoitteesta https://nextcloud.com\">suosittele sitä ystävillesi</a> ja <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">osallistu sen kehittämiseen</a>!"
},
"nplurals=2; plural=(n != 1);");
